# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: string_message.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14string_message.proto\"\x1d\n\rStringMessage\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\tb\x06proto3')



_STRINGMESSAGE = DESCRIPTOR.message_types_by_name['StringMessage']
StringMessage = _reflection.GeneratedProtocolMessageType('StringMessage', (_message.Message,), {
  'DESCRIPTOR' : _STRINGMESSAGE,
  '__module__' : 'string_message_pb2'
  # @@protoc_insertion_point(class_scope:StringMessage)
  })
_sym_db.RegisterMessage(StringMessage)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STRINGMESSAGE._serialized_start=24
  _STRINGMESSAGE._serialized_end=53
# @@protoc_insertion_point(module_scope)



import time
from datetime import datetime

import responses
from faker import Faker
from foxglove_data_platform.client import Client

from .api_url import api_url

fake = Faker()


@responses.activate
def test_create_event():
    id = fake.uuid4()
    device_id = fake.uuid4()
    responses.add(
        responses.POST,
        api_url("/beta/device-events"),
        json={
            "id": id,
            "deviceId": device_id,
            "timestampNanos": str(time.time_ns()),
            "durationNanos": "1",
            "metadata": {"foo": "bar"},
            "createdAt": datetime.now().isoformat(),
            "updatedAt": datetime.now().isoformat(),
        },
    )
    client = Client("test")
    event = client.create_event(device_id=device_id, time=datetime.now(), duration=1)
    assert event["id"] == id
    assert event["device_id"] == device_id


@responses.activate
def test_delete_event():
    id = fake.uuid4()
    responses.add(
        responses.DELETE,
        api_url(f"/beta/device-events/{id}"),
    )
    client = Client("test")
    try:
        client.delete_event(event_id=id)
    except:
        assert False


@responses.activate
def test_get_events():
    device_id = "my_device_id"
    responses.add(
        responses.GET,
        api_url(f"/beta/device-events?deviceId={device_id}"),
        json=[
            {
                "id": "1",
                "createdAt": datetime.now().isoformat(),
                "deviceId": device_id,
                "durationNanos": fake.pyint(),
                "metadata": {},
                "timestampNanos": fake.pyint(),
                "updatedAt": datetime.now().isoformat(),
            }
        ],
    )
    client = Client("test")
    events = client.get_events(device_id=device_id)
    assert len(events) == 1
    assert events[0]["device_id"] == device_id
